Contributing to Twisted
=======================

As an open source project, Twisted welcomes contributions of many forms.
This document summarizes the process.

Twisted has a [Code of Conduct](./code_of_conduct.md).

Examples of contributions include:

* Code patches
* Documentation improvements
* Bug reports
* Pull request reviews

Contributions are managed using GitHub's Pull Requests.
For a PR to be accepted:

* It must have an associated Trac ticket ([file one here](https://twistedmatrix.com/trac/newticket))
* All automated checks must pass
* The changeset must have 100% patch test coverage

Twisted uses Trac to keep track of bugs, feature requests, and associated
patches because GitHub doesn't provide adequate tooling for its community.
You can log in to Trac with your GitHub account.

Extensive contribution guidelines are [available online](https://twistedmatrix.com/trac/wiki/ContributingToTwistedLabs).
